package com.siebre.itx.njb.service;

package ..deTemp.1733492376500;

import com.siebre.configuration.BusinessConfiguration;
import com.siebre.itx.citic.dao.CITICDao;
import com.siebre.policy.temporary.PolicyPaymentDto;
import com.siebre.recon.ReconTransaction;
import com.siebre.recon.service.BaseQueryPolicyDetailProcessor;
import com.siebre.util.FileUtils;
import com.siebre.util.LocalizedMessageLog;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileOutputStream;
import java.io.OutputStreamWriter;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import java.util.Map;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service
public class NJBPaymentReconProcessor extends BaseQueryPolicyDetailProcessor {
  @Autowired
  CITICDao citicDao;
  
  public String getReconcileFileName(Date transDate) {
    return "0062YBTJFJLTB" + this.df.format(transDate) + ".txt";
  }
  
  public void process(ReconTransaction reconTransaction) throws Exception {
    Date startDate = reconTransaction.getPeriodStartDate();
    Date endDate = reconTransaction.getPeriodStartDate();
    BusinessConfiguration configuration = this.configurationManager.getConfigurationByKey("OperationFlag");
    boolean operateFlg = (configuration == null) ? false : configuration.getBooleanValue().booleanValue();
    if (operateFlg) {
      String operationDate = (String)this.configurationManager.getValue("OperationDate", String.class);
      String[] dateArray = operationDate.split("-");
      startDate = this.df.parse(dateArray[0]);
      endDate = this.df.parse(dateArray[1]);
    } 
    LocalizedMessageLog messageLog = this.messageLogManager.newMessageLog();
    SimpleDateFormat dateFormat = new SimpleDateFormat("yyMMdd");
    String startStr = dateFormat.format(startDate);
    String endStr = dateFormat.format(endDate);
    List<PolicyPaymentDto> policyChangeDtos = this.citicManager.getPolicyPaymentsFormCitic("2K", "62", 
        startStr, endStr);
    createPolicyInfoChangeFile(policyChangeDtos, reconTransaction.getTransactionDate(), messageLog);
    String resultMsg = messageLog.getMessage();
    if (StringUtils.isNotBlank(resultMsg))
      reconTransaction.setReconcileMessage(resultMsg); 
  }
  
  private void filterData(Map<String, PolicyPaymentDto> result, List<PolicyPaymentDto> policyChangeDtos) {
    for (PolicyPaymentDto ppd : policyChangeDtos) {
      String policyNum = ppd.getPolicyNum();
      if (result.get(policyNum) == null) {
        result.put(policyNum, ppd);
        continue;
      } 
      int cur = Integer.valueOf(((PolicyPaymentDto)result.get(policyNum)).getTransNo()).intValue();
      int next = Integer.valueOf(ppd.getTransNo()).intValue();
      if (cur < next)
        result.put(policyNum, ppd); 
    } 
  }
  
  private void createPolicyInfoChangeFile(List<PolicyPaymentDto> result, Date transDate, LocalizedMessageLog messageLog) {
    String backDir = (String)this.configurationManager.getValue("NJB_TONJB_DIR", String.class);
    File resultFile = new File(backDir, getReconcileFileName(transDate));
    if (resultFile.exists())
      resultFile.delete(); 
    FileOutputStream fileOutputStream = null;
    OutputStreamWriter outputStreamWriter = null;
    BufferedWriter bufferedWriter = null;
    try {
      resultFile.createNewFile();
      log.info("Creating backFile is success");
      fileOutputStream = new FileOutputStream(resultFile);
      outputStreamWriter = new OutputStreamWriter(fileOutputStream, "GBK");
      bufferedWriter = new BufferedWriter(outputStreamWriter);
      if (result.isEmpty()) {
        messageLog.log("成功生成（中信保诚-南京银行）缴费记录同步出盘文件，文件目录[" + resultFile.getAbsolutePath() + "]。");
        return;
      } 
      for (PolicyPaymentDto policyPaymentDto : result) {
        StringBuilder stringBuilder = new StringBuilder();
        String policyNum = policyPaymentDto.getPolicyNum();
        stringBuilder.append(policyNum).append("|");
        stringBuilder.append(this.df.format(policyPaymentDto.getTransDate())).append("|");
        stringBuilder.append(policyPaymentDto.getAmount()).append("|");
        stringBuilder.append(policyPaymentDto.getAllPayPremium()).append("|");
        stringBuilder.append(StringUtils.trimToEmpty(policyPaymentDto.getBankAccount())).append("|");
        stringBuilder.append("南京银行");
        bufferedWriter.write(stringBuilder.toString());
        bufferedWriter.newLine();
        bufferedWriter.flush();
      } 
      messageLog.log("成功生成（中信保诚-南京银行）缴费记录同步出盘文件，文件目录[" + resultFile.getAbsolutePath() + "]。");
    } catch (Exception exception) {
      log.error("组装缴费记录同步文件失败", exception);
      if (resultFile.exists())
        resultFile.delete(); 
      messageLog.log("生成（中信保诚-南京银行）缴费记录同步出盘文件异常，请联系系统管理员。");
    } finally {
      FileUtils.closeCloseable(bufferedWriter);
      FileUtils.closeCloseable(outputStreamWriter);
      FileUtils.closeCloseable(fileOutputStream);
    } 
  }
}
